emacs-orgmode
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[O] [PATCH] ox.el: Define subtitle macro


From: Jens Lechtenboerger
Subject: [O] [PATCH] ox.el: Define subtitle macro
Date: Thu, 16 Nov 2017 15:08:48 +0100
User-agent: Gnus/5.13 (Gnus v5.13) Emacs/27.0.50 (gnu/linux)

Hi there,

the attached patch adds a subtitle macro with documentation.

Best wishes
Jens

>From 3f54f515847f1f3034274d79fff6cfd1f92c72a9 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Jens=20Lechtenb=C3=B6rger?= <address@hidden>
Date: Thu, 16 Nov 2017 15:03:33 +0100
Subject: [PATCH] Define and document subtitle macro

* lisp/ox.el (org-export-as): Define macro for subtitle.

* lisp/org-macro.el: Mention new macro in comment among others.

* doc/org.texi: Document new macro.
---
 doc/org.texi      | 2 ++
 lisp/org-macro.el | 2 +-
 lisp/ox.el        | 6 ++++--
 3 files changed, 7 insertions(+), 3 deletions(-)

diff --git a/doc/org.texi b/doc/org.texi
index e116a9b..3907eda 100644
--- a/doc/org.texi
+++ b/doc/org.texi
@@ -11080,9 +11080,11 @@ Org comes with following pre-defined macros:
 
 @table @code
 @item @address@hidden@address@hidden@address@hidden
address@hidden @address@hidden@address@hidden@address@hidden
 @itemx @address@hidden@address@hidden@address@hidden
 @itemx @address@hidden@address@hidden@address@hidden
 @cindex title, macro
address@hidden subtitle, macro
 @cindex author, macro
 @cindex email, macro
 Org replaces these macro references with available information at the time of
diff --git a/lisp/org-macro.el b/lisp/org-macro.el
index 1d2823e..c82bfd8 100644
--- a/lisp/org-macro.el
+++ b/lisp/org-macro.el
@@ -43,7 +43,7 @@
 ;;   {{{n(counter,action}}}.
 
 ;; Upon exporting, "ox.el" will also provide {{{author}}}, {{{date}}},
-;; {{{email}}} and {{{title}}} macros.
+;; {{{email}}}, {{{title}}}, and {{{subtitle}}} macros.
 
 ;;; Code:
 (require 'cl-lib)
diff --git a/lisp/ox.el b/lisp/ox.el
index cc3c48b..6feec3e 100644
--- a/lisp/ox.el
+++ b/lisp/ox.el
@@ -3083,8 +3083,8 @@ Return code as a string."
             (let ((result (funcall filter info backend-name)))
               (when result (setq info result)))))
         ;; Expand export-specific set of macros: {{{author}}},
         ;; {{{date(FORMAT)}}}, {{{email}}} and {{{title}}}.  It must
         ;; be done once regular macros have been expanded, since
         ;; parsed keywords may contain one of them.
         (org-macro-replace-all
          (list
@@ -3102,6 +3102,8 @@ Return code as a string."
                     value)))
           (cons "email" (org-element-interpret-data (plist-get info :email)))
           (cons "title" (org-element-interpret-data (plist-get info :title)))
+          (cons "subtitle"
+                (org-element-interpret-data (plist-get info :subtitle)))
           (cons "results" "$1"))
          'finalize
          parsed-keywords)
@@ -3083,8 +3083,8 @@ Return code as a string."
               (when result (setq info result)))))
         ;; Expand export-specific set of macros: {{{author}}},
-        ;; {{{date(FORMAT)}}}, {{{email}}} and {{{title}}}.  It must
-        ;; be done once regular macros have been expanded, since
+        ;; {{{date(FORMAT)}}}, {{{email}}}, {{{title}}}, and {{{subtitle}}}.
+        ;; It must be done once regular macros have been expanded, since
         ;; parsed keywords may contain one of them.
         (org-macro-replace-all
-- 
2.1.4


reply via email to

[Prev in Thread] Current Thread [Next in Thread]